# Introduction

The `eqdsk` package provides a convenient interface to eqdsk files.

It can read and write .eqdsk (g-eqdsk) and .json formats.

There is built-in COCOS support, for identifying and converting between different COCOS versions.

## Examples

See [examples](examples/using_api) for how to use the package.
